pyjabber.utils package
======================

Submodules
----------

pyjabber.utils.ClarkNotation module
-----------------------------------

.. automodule:: pyjabber.utils.ClarkNotation
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.utils.Singleton module
-------------------------------

.. automodule:: pyjabber.utils.Singleton
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.utils
   :members:
   :undoc-members:
   :show-inheritance:
